Acr

Struct Acr 

pub struct Acr(/* private fields */);
An Authentication Context Class Reference, as defined in the OpenID Connect specification.

ACRs are opaque, non-empty tokens containing no whitespace.

Implementations

Source

impl Acr

pub fn as_str(&self) -> &str

Available on crate feature events only.

Extracts a string slice from this Acr.

pub fn as_bytes(&self) -> &[u8] ⓘ

Available on crate feature events only.

Extracts a byte slice from this Acr.

Source

impl Acr

pub fn parse(s: impl AsRef<str>) -> Result<OwnedAcr, Error>

Available on crate feature events only.

Try parsing a &str into an OwnedAcr.

The same can also be done using FromStr, TryFrom or TryInto. This function is simply more constrained and thus useful in generic contexts.