pub struct ClientSecret(/* private fields */);Expand description
A client secret.
Client secrets in Matrix are opaque character sequences of [0-9a-zA-Z.=_-]. Their length must
must not exceed 255 characters.
You can create one from a string (using ClientSecret::parse()) but the recommended way is to
use ClientSecret::new() to generate a random one. If that function is not available for you,
you need to activate this crate’s rand Cargo feature.
Implementations
Sourceimpl ClientSecret
impl ClientSecret
Sourceimpl ClientSecret
impl ClientSecret
Sourceimpl ClientSecret
impl ClientSecret
Sourcepub fn new() -> OwnedClientSecret
Available on crate features events and rand only.
pub fn new() -> OwnedClientSecret
events and rand only.Creates a random client secret.
This will currently be a UUID without hyphens, but no guarantees are made about the structure of client secrets generated from this function.