pub struct OwnedBase64PublicKey { /* private fields */ }Expand description
Owned variant of Base64PublicKey
Inner representation
By default, this type uses a Box<str> internally. The inner representation can be selected at
compile time by using one of the following supported values:
Arc– Use anArc<str>.
The selected value can be set by using the ruma_identifiers_storage compile-time cfg setting.
This setting can be configured using the RUSTFLAGS environment variable at build time, like this:
RUSTFLAGS="--cfg ruma_identifiers_storage=\"{value}\""Or in .cargo/config.toml:
# General setting for all targets, overridden by per-target `rustflags` setting if set.
[build]
rustflags = ["--cfg", "ruma_identifiers_storage=\"{value}\""]
# Per-target setting.
[target.<triple/cfg>]
rustflags = ["--cfg", "ruma_identifiers_storage=\"{value}\""]This setting can also be configured using the RUMA_IDENTIFIERS_STORAGE environment variable at
compile time, which has the benefit of not requiring to re-compile the whole dependency chain
when the value is changed, like this:
RUMA_IDENTIFIERS_STORAGE="{value}"Implementations
Sourceimpl OwnedBase64PublicKey
impl OwnedBase64PublicKey
Sourcepub fn with_bytes<B>(bytes: B) -> OwnedBase64PublicKey
Available on crate feature events only.
pub fn with_bytes<B>(bytes: B) -> OwnedBase64PublicKey
events only.Construct a new OwnedBase64PublicKey by encoding the given bytes using unpadded base64.
Methods from Deref<Target = Base64PublicKey>