pub struct OwnedDeviceId { /* private fields */ }Expand description
Owned variant of DeviceId
Inner representation
By default, this type uses a Box<str> internally. The inner representation can be selected at
compile time by using one of the following supported values:
Arc– Use anArc<str>.
The selected value can be set by using the ruma_identifiers_storage compile-time cfg setting.
This setting can be configured using the RUSTFLAGS environment variable at build time, like this:
RUSTFLAGS="--cfg ruma_identifiers_storage=\"{value}\""Or in .cargo/config.toml:
# General setting for all targets, overridden by per-target `rustflags` setting if set.
[build]
rustflags = ["--cfg", "ruma_identifiers_storage=\"{value}\""]
# Per-target setting.
[target.<triple/cfg>]
rustflags = ["--cfg", "ruma_identifiers_storage=\"{value}\""]This setting can also be configured using the RUMA_IDENTIFIERS_STORAGE environment variable at
compile time, which has the benefit of not requiring to re-compile the whole dependency chain
when the value is changed, like this:
RUMA_IDENTIFIERS_STORAGE="{value}"Trait Implementations
Sourceimpl AsRef<[u8]> for OwnedDeviceId
impl AsRef<[u8]> for OwnedDeviceId
Sourceimpl AsRef<DeviceId> for OwnedDeviceId
impl AsRef<DeviceId> for OwnedDeviceId
Sourceimpl AsRef<str> for OwnedDeviceId
impl AsRef<str> for OwnedDeviceId
Sourceimpl Borrow<DeviceId> for OwnedDeviceId
impl Borrow<DeviceId> for OwnedDeviceId
Sourceimpl Clone for OwnedDeviceId
impl Clone for OwnedDeviceId
Sourcefn clone(&self) -> OwnedDeviceId
fn clone(&self) -> OwnedDeviceId
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OwnedDeviceId
impl Debug for OwnedDeviceId
Sourceimpl Deref for OwnedDeviceId
impl Deref for OwnedDeviceId
Sourceimpl<'de> Deserialize<'de> for OwnedDeviceId
impl<'de> Deserialize<'de> for OwnedDeviceId
Sourcefn deserialize<D>(
deserializer: D,
) -> Result<OwnedDeviceId, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
fn deserialize<D>(
deserializer: D,
) -> Result<OwnedDeviceId, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for OwnedDeviceId
impl Display for OwnedDeviceId
Sourceimpl From<&DeviceId> for OwnedDeviceId
impl From<&DeviceId> for OwnedDeviceId
Sourcefn from(id: &DeviceId) -> OwnedDeviceId
fn from(id: &DeviceId) -> OwnedDeviceId
Converts to this type from the input type.
Sourceimpl From<&str> for OwnedDeviceId
impl From<&str> for OwnedDeviceId
Sourcefn from(s: &str) -> OwnedDeviceId
fn from(s: &str) -> OwnedDeviceId
Converts to this type from the input type.
Sourceimpl From<OwnedDeviceId> for DeviceIdOrAllDevices
impl From<OwnedDeviceId> for DeviceIdOrAllDevices
Sourcefn from(d: OwnedDeviceId) -> DeviceIdOrAllDevices
fn from(d: OwnedDeviceId) -> DeviceIdOrAllDevices
Converts to this type from the input type.
Sourceimpl From<OwnedDeviceId> for OwnedBase64PublicKeyOrDeviceId
impl From<OwnedDeviceId> for OwnedBase64PublicKeyOrDeviceId
Sourcefn from(value: OwnedDeviceId) -> OwnedBase64PublicKeyOrDeviceId
fn from(value: OwnedDeviceId) -> OwnedBase64PublicKeyOrDeviceId
Converts to this type from the input type.
Sourceimpl From<OwnedDeviceId> for String
impl From<OwnedDeviceId> for String
Sourcefn from(id: OwnedDeviceId) -> String
fn from(id: OwnedDeviceId) -> String
Converts to this type from the input type.
Sourceimpl From<String> for OwnedDeviceId
impl From<String> for OwnedDeviceId
Sourcefn from(s: String) -> OwnedDeviceId
fn from(s: String) -> OwnedDeviceId
Converts to this type from the input type.
Sourceimpl Hash for OwnedDeviceId
impl Hash for OwnedDeviceId
Sourceimpl KeyName for OwnedDeviceId
impl KeyName for OwnedDeviceId
Sourceimpl Ord for OwnedDeviceId
impl Ord for OwnedDeviceId
Sourcefn cmp(&self, other: &OwnedDeviceId) -> Ordering
fn cmp(&self, other: &OwnedDeviceId) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq<&DeviceId> for OwnedDeviceId
impl PartialEq<&DeviceId> for OwnedDeviceId
Sourceimpl PartialEq<&str> for OwnedDeviceId
impl PartialEq<&str> for OwnedDeviceId
Sourceimpl PartialEq<DeviceId> for OwnedDeviceId
impl PartialEq<DeviceId> for OwnedDeviceId
Sourceimpl PartialEq<OwnedDeviceId> for &DeviceId
impl PartialEq<OwnedDeviceId> for &DeviceId
Sourceimpl PartialEq<OwnedDeviceId> for &str
impl PartialEq<OwnedDeviceId> for &str
Sourceimpl PartialEq<OwnedDeviceId> for DeviceId
impl PartialEq<OwnedDeviceId> for DeviceId
Sourceimpl PartialEq<OwnedDeviceId> for str
impl PartialEq<OwnedDeviceId> for str
Sourceimpl PartialEq<String> for OwnedDeviceId
impl PartialEq<String> for OwnedDeviceId
Sourceimpl PartialEq<str> for OwnedDeviceId
impl PartialEq<str> for OwnedDeviceId
Sourceimpl PartialEq for OwnedDeviceId
impl PartialEq for OwnedDeviceId
Sourceimpl PartialOrd for OwnedDeviceId
impl PartialOrd for OwnedDeviceId
Sourceimpl Serialize for OwnedDeviceId
impl Serialize for OwnedDeviceId
Sourcefn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
fn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Eq for OwnedDeviceId