pub struct OwnedRoomAliasId { /* private fields */ }Expand description
Owned variant of RoomAliasId
Inner representation
By default, this type uses a Box<str> internally. The inner representation can be selected at
compile time by using one of the following supported values:
Arc– Use anArc<str>.
The selected value can be set by using the ruma_identifiers_storage compile-time cfg setting.
This setting can be configured using the RUSTFLAGS environment variable at build time, like this:
RUSTFLAGS="--cfg ruma_identifiers_storage=\"{value}\""Or in .cargo/config.toml:
# General setting for all targets, overridden by per-target `rustflags` setting if set.
[build]
rustflags = ["--cfg", "ruma_identifiers_storage=\"{value}\""]
# Per-target setting.
[target.<triple/cfg>]
rustflags = ["--cfg", "ruma_identifiers_storage=\"{value}\""]This setting can also be configured using the RUMA_IDENTIFIERS_STORAGE environment variable at
compile time, which has the benefit of not requiring to re-compile the whole dependency chain
when the value is changed, like this:
RUMA_IDENTIFIERS_STORAGE="{value}"Methods from Deref<Target = RoomAliasId>
Sourcepub fn as_str(&self) -> &str
Available on crate feature events only.
pub fn as_str(&self) -> &str
events only.Extracts a string slice from this RoomAliasId.
Sourcepub fn as_bytes(&self) -> &[u8] ⓘ
Available on crate feature events only.
pub fn as_bytes(&self) -> &[u8] ⓘ
events only.Extracts a byte slice from this RoomAliasId.
Sourcepub fn server_name(&self) -> &ServerName
Available on crate feature events only.
pub fn server_name(&self) -> &ServerName
events only.Returns the server name of the room alias ID.
Sourcepub fn matrix_to_uri(&self) -> MatrixToUri
Available on crate feature events only.
pub fn matrix_to_uri(&self) -> MatrixToUri
events only.Create a matrix.to URI for this room alias ID.
Sourcepub fn matrix_to_event_uri(&self, ev_id: impl Into<OwnedEventId>) -> MatrixToUri
👎Deprecated: Use RoomId::matrix_to_event_uri instead.Available on crate feature events only.
pub fn matrix_to_event_uri(&self, ev_id: impl Into<OwnedEventId>) -> MatrixToUri
RoomId::matrix_to_event_uri instead.events only.Create a matrix.to URI for an event scoped under this room alias ID.
This is deprecated because room aliases are mutable, so the URI might break after a while.
Sourcepub fn matrix_uri(&self, join: bool) -> MatrixUri
Available on crate feature events only.
pub fn matrix_uri(&self, join: bool) -> MatrixUri
events only.Create a matrix: URI for this room alias ID.
If join is true, a click on the URI should join the room.
Sourcepub fn matrix_event_uri(&self, ev_id: impl Into<OwnedEventId>) -> MatrixUri
👎Deprecated: Use RoomId::matrix_event_uri instead.Available on crate feature events only.
pub fn matrix_event_uri(&self, ev_id: impl Into<OwnedEventId>) -> MatrixUri
RoomId::matrix_event_uri instead.events only.Create a matrix: URI for an event scoped under this room alias ID.
This is deprecated because room aliases are mutable, so the URI might break after a while.