pub struct OwnedRoomOrAliasId { /* private fields */ }Expand description
Owned variant of RoomOrAliasId
Inner representation
By default, this type uses a Box<str> internally. The inner representation can be selected at
compile time by using one of the following supported values:
Arc– Use anArc<str>.
The selected value can be set by using the ruma_identifiers_storage compile-time cfg setting.
This setting can be configured using the RUSTFLAGS environment variable at build time, like this:
RUSTFLAGS="--cfg ruma_identifiers_storage=\"{value}\""Or in .cargo/config.toml:
# General setting for all targets, overridden by per-target `rustflags` setting if set.
[build]
rustflags = ["--cfg", "ruma_identifiers_storage=\"{value}\""]
# Per-target setting.
[target.<triple/cfg>]
rustflags = ["--cfg", "ruma_identifiers_storage=\"{value}\""]This setting can also be configured using the RUMA_IDENTIFIERS_STORAGE environment variable at
compile time, which has the benefit of not requiring to re-compile the whole dependency chain
when the value is changed, like this:
RUMA_IDENTIFIERS_STORAGE="{value}"Methods from Deref<Target = RoomOrAliasId>
Sourcepub fn as_str(&self) -> &str
Available on crate feature events only.
pub fn as_str(&self) -> &str
events only.Extracts a string slice from this RoomOrAliasId.
Sourcepub fn as_bytes(&self) -> &[u8] ⓘ
Available on crate feature events only.
pub fn as_bytes(&self) -> &[u8] ⓘ
events only.Extracts a byte slice from this RoomOrAliasId.
Sourcepub fn server_name(&self) -> Option<&ServerName>
Available on crate feature events only.
pub fn server_name(&self) -> Option<&ServerName>
events only.Returns the server name of the room (alias) ID.
Sourcepub fn is_room_id(&self) -> bool
Available on crate feature events only.
pub fn is_room_id(&self) -> bool
events only.Whether this is a room id (starts with '!')
Sourcepub fn is_room_alias_id(&self) -> bool
Available on crate feature events only.
pub fn is_room_alias_id(&self) -> bool
events only.Whether this is a room alias id (starts with '#')