pub struct OwnedServerName { /* private fields */ }Expand description
Owned variant of ServerName
Inner representation
By default, this type uses a Box<str> internally. The inner representation can be selected at
compile time by using one of the following supported values:
Arc– Use anArc<str>.
The selected value can be set by using the ruma_identifiers_storage compile-time cfg setting.
This setting can be configured using the RUSTFLAGS environment variable at build time, like this:
RUSTFLAGS="--cfg ruma_identifiers_storage=\"{value}\""Or in .cargo/config.toml:
# General setting for all targets, overridden by per-target `rustflags` setting if set.
[build]
rustflags = ["--cfg", "ruma_identifiers_storage=\"{value}\""]
# Per-target setting.
[target.<triple/cfg>]
rustflags = ["--cfg", "ruma_identifiers_storage=\"{value}\""]This setting can also be configured using the RUMA_IDENTIFIERS_STORAGE environment variable at
compile time, which has the benefit of not requiring to re-compile the whole dependency chain
when the value is changed, like this:
RUMA_IDENTIFIERS_STORAGE="{value}"Implementations
Sourceimpl OwnedServerName
impl OwnedServerName
Sourcepub fn zeroize(self)
Available on crate feature events only.
pub fn zeroize(self)
events only.Securely zero memory (aka zeroize) of OwnedServerName.
This method zeroizes this type by writing zeros in its
memory location before freeing it. It internally uses
the zeroize crate. Note that this type
doesn’t implement the zeroize::Zeroize trait because the
Zeroize::zeroize method takes a &mut self, which means
we could put this type into an inconsistent state if it is
used after calling that method. Instead, this method takes
ownership of the type, ensuring it’s impossible to misuse
it.
Implementation details
If the ruma_identifiers_storage configuration is
set to Arc, this type will be zeroized if and only if
Arc::get_mut returns Some reference, i.e. if there is no
other Arc or Weak pointers to this same location.
Methods from Deref<Target = ServerName>
Sourcepub fn as_str(&self) -> &str
Available on crate feature events only.
pub fn as_str(&self) -> &str
events only.Extracts a string slice from this ServerName.
Sourcepub fn as_bytes(&self) -> &[u8] ⓘ
Available on crate feature events only.
pub fn as_bytes(&self) -> &[u8] ⓘ
events only.Extracts a byte slice from this ServerName.
Sourcepub fn host(&self) -> &str
Available on crate feature events only.
pub fn host(&self) -> &str
events only.Returns the host of the server name.
That is: Return the part of the server name before :<port> or the full server name if
there is no port.
Sourcepub fn port(&self) -> Option<u16>
Available on crate feature events only.
pub fn port(&self) -> Option<u16>
events only.Returns the port of the server name, if any.
Sourcepub fn is_ip_literal(&self) -> bool
Available on crate feature events only.
pub fn is_ip_literal(&self) -> bool
events only.Returns true if and only if the server name is an IPv4 or IPv6 address.