pub struct RoomAliasId(/* private fields */);Expand description
A Matrix room alias ID.
A RoomAliasId is converted from a string slice, and can be converted back into a string as
needed.
assert_eq!(<&RoomAliasId>::try_from("#ruma:example.com").unwrap(), "#ruma:example.com");Implementations
Sourceimpl RoomAliasId
impl RoomAliasId
Sourceimpl RoomAliasId
impl RoomAliasId
Sourceimpl RoomAliasId
impl RoomAliasId
Sourcepub fn server_name(&self) -> &ServerName
Available on crate feature events only.
pub fn server_name(&self) -> &ServerName
events only.Returns the server name of the room alias ID.
Sourcepub fn matrix_to_uri(&self) -> MatrixToUri
Available on crate feature events only.
pub fn matrix_to_uri(&self) -> MatrixToUri
events only.Create a matrix.to URI for this room alias ID.
Sourcepub fn matrix_to_event_uri(&self, ev_id: impl Into<OwnedEventId>) -> MatrixToUri
👎Deprecated: Use RoomId::matrix_to_event_uri instead.Available on crate feature events only.
pub fn matrix_to_event_uri(&self, ev_id: impl Into<OwnedEventId>) -> MatrixToUri
RoomId::matrix_to_event_uri instead.events only.Create a matrix.to URI for an event scoped under this room alias ID.
This is deprecated because room aliases are mutable, so the URI might break after a while.
Sourcepub fn matrix_uri(&self, join: bool) -> MatrixUri
Available on crate feature events only.
pub fn matrix_uri(&self, join: bool) -> MatrixUri
events only.Create a matrix: URI for this room alias ID.
If join is true, a click on the URI should join the room.
Sourcepub fn matrix_event_uri(&self, ev_id: impl Into<OwnedEventId>) -> MatrixUri
👎Deprecated: Use RoomId::matrix_event_uri instead.Available on crate feature events only.
pub fn matrix_event_uri(&self, ev_id: impl Into<OwnedEventId>) -> MatrixUri
RoomId::matrix_event_uri instead.events only.Create a matrix: URI for an event scoped under this room alias ID.
This is deprecated because room aliases are mutable, so the URI might break after a while.