pub struct RoomOrAliasId(/* private fields */);Expand description
A Matrix room ID or a Matrix room alias ID.
RoomOrAliasId is useful for APIs that accept either kind of room identifier. It is converted
from a string slice, and can be converted back into a string as needed. When converted from a
string slice, the variant is determined by the leading sigil character.
assert_eq!(<&RoomOrAliasId>::try_from("#ruma:example.com").unwrap(), "#ruma:example.com");
assert_eq!(
<&RoomOrAliasId>::try_from("!n8f893n9:example.com").unwrap(),
"!n8f893n9:example.com"
);It can be converted to a RoomId or a RoomAliasId using ::try_from() / .try_into().
For example, <&RoomId>::try_from(room_or_alias_id) returns either Ok(room_id) or
Err(room_alias_id).
Implementations
Sourceimpl RoomOrAliasId
impl RoomOrAliasId
Sourceimpl RoomOrAliasId
impl RoomOrAliasId
Sourceimpl RoomOrAliasId
impl RoomOrAliasId
Sourcepub fn server_name(&self) -> Option<&ServerName>
Available on crate feature events only.
pub fn server_name(&self) -> Option<&ServerName>
events only.Returns the server name of the room (alias) ID.
Sourcepub fn is_room_id(&self) -> bool
Available on crate feature events only.
pub fn is_room_id(&self) -> bool
events only.Whether this is a room id (starts with '!')
Sourcepub fn is_room_alias_id(&self) -> bool
Available on crate feature events only.
pub fn is_room_alias_id(&self) -> bool
events only.Whether this is a room alias id (starts with '#')