pub struct OwnedKeyId<A, K>{ /* private fields */ }Expand description
Owned variant of KeyId
Inner representation
By default, this type uses a Box<str> internally. The inner representation can be selected at
compile time by using one of the following supported values:
Arc– Use anArc<str>.
The selected value can be set by using the ruma_identifiers_storage compile-time cfg setting.
This setting can be configured using the RUSTFLAGS environment variable at build time, like this:
RUSTFLAGS="--cfg ruma_identifiers_storage=\"{value}\""Or in .cargo/config.toml:
# General setting for all targets, overridden by per-target `rustflags` setting if set.
[build]
rustflags = ["--cfg", "ruma_identifiers_storage=\"{value}\""]
# Per-target setting.
[target.<triple/cfg>]
rustflags = ["--cfg", "ruma_identifiers_storage=\"{value}\""]This setting can also be configured using the RUMA_IDENTIFIERS_STORAGE environment variable at
compile time, which has the benefit of not requiring to re-compile the whole dependency chain
when the value is changed, like this:
RUMA_IDENTIFIERS_STORAGE="{value}"Methods from Deref<Target = KeyId<A, K>>
Sourcepub fn as_str(&self) -> &str
Available on crate feature events only.
pub fn as_str(&self) -> &str
events only.Extracts a string slice from this KeyId.
Sourcepub fn as_bytes(&self) -> &[u8] ⓘ
Available on crate feature events only.
pub fn as_bytes(&self) -> &[u8] ⓘ
events only.Extracts a byte slice from this KeyId.
Sourcepub fn algorithm(&self) -> A
Available on crate feature events only.
pub fn algorithm(&self) -> A
events only.Returns key algorithm of the key ID - the part that comes before the colon.
Example
use ruma_common::{DeviceKeyAlgorithm, DeviceKeyId};
let k = DeviceKeyId::parse("ed25519:1").unwrap();
assert_eq!(k.algorithm(), DeviceKeyAlgorithm::Ed25519);Sourcepub fn key_name<'a>(&'a self) -> &'a K
Available on crate feature events only.
pub fn key_name<'a>(&'a self) -> &'a K
events only.Returns the key name of the key ID - the part that comes after the colon.
Example
use ruma_common::{DeviceKeyId, device_id};
let k = DeviceKeyId::parse("ed25519:DEV1").unwrap();
assert_eq!(k.key_name(), device_id!("DEV1"));Trait Implementations
Sourceimpl<A, K> AsRef<[u8]> for OwnedKeyId<A, K>
impl<A, K> AsRef<[u8]> for OwnedKeyId<A, K>
Sourceimpl<A, K> AsRef<KeyId<A, K>> for OwnedKeyId<A, K>
impl<A, K> AsRef<KeyId<A, K>> for OwnedKeyId<A, K>
Sourceimpl<A, K> AsRef<str> for OwnedKeyId<A, K>
impl<A, K> AsRef<str> for OwnedKeyId<A, K>
Sourceimpl<A, K> Borrow<KeyId<A, K>> for OwnedKeyId<A, K>
impl<A, K> Borrow<KeyId<A, K>> for OwnedKeyId<A, K>
Sourceimpl<A, K> Clone for OwnedKeyId<A, K>
impl<A, K> Clone for OwnedKeyId<A, K>
Sourcefn clone(&self) -> OwnedKeyId<A, K>
fn clone(&self) -> OwnedKeyId<A, K>
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl<A, K> Debug for OwnedKeyId<A, K>
impl<A, K> Debug for OwnedKeyId<A, K>
Sourceimpl<A, K> Deref for OwnedKeyId<A, K>
impl<A, K> Deref for OwnedKeyId<A, K>
Sourceimpl<'de, A, K> Deserialize<'de> for OwnedKeyId<A, K>
impl<'de, A, K> Deserialize<'de> for OwnedKeyId<A, K>
Sourcefn deserialize<D>(
deserializer: D,
) -> Result<OwnedKeyId<A, K>, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
fn deserialize<D>(
deserializer: D,
) -> Result<OwnedKeyId<A, K>, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
Sourceimpl<A, K> Display for OwnedKeyId<A, K>
impl<A, K> Display for OwnedKeyId<A, K>
Sourceimpl<A, K> From<&KeyId<A, K>> for OwnedKeyId<A, K>
impl<A, K> From<&KeyId<A, K>> for OwnedKeyId<A, K>
Sourcefn from(id: &KeyId<A, K>) -> OwnedKeyId<A, K>
fn from(id: &KeyId<A, K>) -> OwnedKeyId<A, K>
Sourceimpl<A, K> From<OwnedKeyId<A, K>> for String
impl<A, K> From<OwnedKeyId<A, K>> for String
Sourcefn from(id: OwnedKeyId<A, K>) -> String
fn from(id: OwnedKeyId<A, K>) -> String
Sourceimpl<A, K> FromStr for OwnedKeyId<A, K>
impl<A, K> FromStr for OwnedKeyId<A, K>
Sourceimpl<A, K> Hash for OwnedKeyId<A, K>
impl<A, K> Hash for OwnedKeyId<A, K>
Sourceimpl<A, K> Ord for OwnedKeyId<A, K>
impl<A, K> Ord for OwnedKeyId<A, K>
Sourcefn cmp(&self, other: &OwnedKeyId<A, K>) -> Ordering
fn cmp(&self, other: &OwnedKeyId<A, K>) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Sourceimpl<A, K> PartialEq<&KeyId<A, K>> for OwnedKeyId<A, K>
impl<A, K> PartialEq<&KeyId<A, K>> for OwnedKeyId<A, K>
Sourceimpl<A, K> PartialEq<&str> for OwnedKeyId<A, K>
impl<A, K> PartialEq<&str> for OwnedKeyId<A, K>
Sourceimpl<A, K> PartialEq<KeyId<A, K>> for OwnedKeyId<A, K>
impl<A, K> PartialEq<KeyId<A, K>> for OwnedKeyId<A, K>
Sourceimpl<A, K> PartialEq<OwnedKeyId<A, K>> for &KeyId<A, K>
impl<A, K> PartialEq<OwnedKeyId<A, K>> for &KeyId<A, K>
Sourceimpl<A, K> PartialEq<OwnedKeyId<A, K>> for &str
impl<A, K> PartialEq<OwnedKeyId<A, K>> for &str
Sourceimpl<A, K> PartialEq<OwnedKeyId<A, K>> for KeyId<A, K>
impl<A, K> PartialEq<OwnedKeyId<A, K>> for KeyId<A, K>
Sourceimpl<A, K> PartialEq<OwnedKeyId<A, K>> for str
impl<A, K> PartialEq<OwnedKeyId<A, K>> for str
Sourceimpl<A, K> PartialEq<String> for OwnedKeyId<A, K>
impl<A, K> PartialEq<String> for OwnedKeyId<A, K>
Sourceimpl<A, K> PartialEq<str> for OwnedKeyId<A, K>
impl<A, K> PartialEq<str> for OwnedKeyId<A, K>
Sourceimpl<A, K> PartialEq for OwnedKeyId<A, K>
impl<A, K> PartialEq for OwnedKeyId<A, K>
Sourceimpl<A, K> PartialOrd for OwnedKeyId<A, K>
impl<A, K> PartialOrd for OwnedKeyId<A, K>
Sourceimpl<A, K> Serialize for OwnedKeyId<A, K>
impl<A, K> Serialize for OwnedKeyId<A, K>
Sourcefn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
fn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
Sourceimpl<A, K> TryFrom<&str> for OwnedKeyId<A, K>
impl<A, K> TryFrom<&str> for OwnedKeyId<A, K>
Sourceimpl<A, K> TryFrom<String> for OwnedKeyId<A, K>
impl<A, K> TryFrom<String> for OwnedKeyId<A, K>
impl<A, K> Eq for OwnedKeyId<A, K>