pub struct OwnedVoipId { /* private fields */ }Expand description
Owned variant of VoipId
Inner representation
By default, this type uses a Box<str> internally. The inner representation can be selected at
compile time by using one of the following supported values:
Arc– Use anArc<str>.
The selected value can be set by using the ruma_identifiers_storage compile-time cfg setting.
This setting can be configured using the RUSTFLAGS environment variable at build time, like this:
RUSTFLAGS="--cfg ruma_identifiers_storage=\"{value}\""Or in .cargo/config.toml:
# General setting for all targets, overridden by per-target `rustflags` setting if set.
[build]
rustflags = ["--cfg", "ruma_identifiers_storage=\"{value}\""]
# Per-target setting.
[target.<triple/cfg>]
rustflags = ["--cfg", "ruma_identifiers_storage=\"{value}\""]This setting can also be configured using the RUMA_IDENTIFIERS_STORAGE environment variable at
compile time, which has the benefit of not requiring to re-compile the whole dependency chain
when the value is changed, like this:
RUMA_IDENTIFIERS_STORAGE="{value}"Trait Implementations
Sourceimpl AsRef<[u8]> for OwnedVoipId
impl AsRef<[u8]> for OwnedVoipId
Sourceimpl AsRef<VoipId> for OwnedVoipId
impl AsRef<VoipId> for OwnedVoipId
Sourceimpl AsRef<str> for OwnedVoipId
impl AsRef<str> for OwnedVoipId
Sourceimpl Borrow<VoipId> for OwnedVoipId
impl Borrow<VoipId> for OwnedVoipId
Sourceimpl Clone for OwnedVoipId
impl Clone for OwnedVoipId
Sourcefn clone(&self) -> OwnedVoipId
fn clone(&self) -> OwnedVoipId
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OwnedVoipId
impl Debug for OwnedVoipId
Sourceimpl Deref for OwnedVoipId
impl Deref for OwnedVoipId
Sourceimpl<'de> Deserialize<'de> for OwnedVoipId
impl<'de> Deserialize<'de> for OwnedVoipId
Sourcefn deserialize<D>(
deserializer: D,
) -> Result<OwnedVoipId, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
fn deserialize<D>(
deserializer: D,
) -> Result<OwnedVoipId, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for OwnedVoipId
impl Display for OwnedVoipId
Sourceimpl From<&VoipId> for OwnedVoipId
impl From<&VoipId> for OwnedVoipId
Sourcefn from(id: &VoipId) -> OwnedVoipId
fn from(id: &VoipId) -> OwnedVoipId
Converts to this type from the input type.
Sourceimpl From<&str> for OwnedVoipId
impl From<&str> for OwnedVoipId
Sourcefn from(s: &str) -> OwnedVoipId
fn from(s: &str) -> OwnedVoipId
Converts to this type from the input type.
Sourceimpl From<OwnedVoipId> for String
impl From<OwnedVoipId> for String
Sourcefn from(id: OwnedVoipId) -> String
fn from(id: OwnedVoipId) -> String
Converts to this type from the input type.
Sourceimpl From<String> for OwnedVoipId
impl From<String> for OwnedVoipId
Sourcefn from(s: String) -> OwnedVoipId
fn from(s: String) -> OwnedVoipId
Converts to this type from the input type.
Sourceimpl Hash for OwnedVoipId
impl Hash for OwnedVoipId
Sourceimpl Ord for OwnedVoipId
impl Ord for OwnedVoipId
Sourcefn cmp(&self, other: &OwnedVoipId) -> Ordering
fn cmp(&self, other: &OwnedVoipId) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq<&VoipId> for OwnedVoipId
impl PartialEq<&VoipId> for OwnedVoipId
Sourceimpl PartialEq<&str> for OwnedVoipId
impl PartialEq<&str> for OwnedVoipId
Sourceimpl PartialEq<OwnedVoipId> for &VoipId
impl PartialEq<OwnedVoipId> for &VoipId
Sourceimpl PartialEq<OwnedVoipId> for &str
impl PartialEq<OwnedVoipId> for &str
Sourceimpl PartialEq<OwnedVoipId> for VoipId
impl PartialEq<OwnedVoipId> for VoipId
Sourceimpl PartialEq<OwnedVoipId> for str
impl PartialEq<OwnedVoipId> for str
Sourceimpl PartialEq<String> for OwnedVoipId
impl PartialEq<String> for OwnedVoipId
Sourceimpl PartialEq<VoipId> for OwnedVoipId
impl PartialEq<VoipId> for OwnedVoipId
Sourceimpl PartialEq<str> for OwnedVoipId
impl PartialEq<str> for OwnedVoipId
Sourceimpl PartialEq for OwnedVoipId
impl PartialEq for OwnedVoipId
Sourceimpl PartialOrd for OwnedVoipId
impl PartialOrd for OwnedVoipId
Sourceimpl Serialize for OwnedVoipId
impl Serialize for OwnedVoipId
Sourcefn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
fn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Eq for OwnedVoipId